summaryrefslogtreecommitdiffstats
path: root/kcachegrind/kcachegrind/callgraphview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcachegrind/kcachegrind/callgraphview.cpp')
-rw-r--r--kcachegrind/kcachegrind/callgraphview.cpp104
1 files changed, 52 insertions, 52 deletions
diff --git a/kcachegrind/kcachegrind/callgraphview.cpp b/kcachegrind/kcachegrind/callgraphview.cpp
index f9d06e68..5fc8dbb3 100644
--- a/kcachegrind/kcachegrind/callgraphview.cpp
+++ b/kcachegrind/kcachegrind/callgraphview.cpp
@@ -25,7 +25,7 @@
#include <tqtooltip.h>
#include <tqfile.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqwhatsthis.h>
#include <tqcanvas.h>
#include <tqwmatrix.h>
@@ -303,8 +303,8 @@ GraphEdge::GraphEdge()
TQString GraphEdge::prettyName()
{
if (_c) return _c->prettyName();
- if (_from) return i18n("Call(s) from %1").arg(_from->prettyName());
- if (_to) return i18n("Call(s) to %1").arg(_to->prettyName());
+ if (_from) return i18n("Call(s) from %1").tqarg(_from->prettyName());
+ if (_to) return i18n("Call(s) to %1").tqarg(_to->prettyName());
return i18n("(unknown call)");
}
@@ -376,7 +376,7 @@ TQString GraphOptions::layoutString(Layout l)
return TQString("TopDown");
}
-GraphOptions::Layout GraphOptions::layout(TQString s)
+GraphOptions::Layout GraphOptions::tqlayout(TQString s)
{
if (s == TQString("Circular")) return Circular;
if (s == TQString("LeftRight")) return LeftRight;
@@ -562,10 +562,10 @@ void GraphExporter::writeDot()
*stream << "digraph \"callgraph\" {\n";
- if (_go->layout() == LeftRight) {
+ if (_go->tqlayout() == LeftRight) {
*stream << TQString(" rankdir=LR;\n");
}
- else if (_go->layout() == Circular) {
+ else if (_go->tqlayout() == Circular) {
TraceFunction *f = 0;
switch(_item->type()) {
case TraceItem::Function:
@@ -579,7 +579,7 @@ void GraphExporter::writeDot()
break;
}
if (f)
- *stream << TQString(" center=F%1;\n").arg((long)f, 0, 16);
+ *stream << TQString(" center=F%1;\n").tqarg((long)f, 0, 16);
*stream << TQString(" overlap=false;\n splines=true;\n");
}
@@ -619,7 +619,7 @@ void GraphExporter::writeDot()
iabr = iabr.left(Configuration::maxSymbolLength()) + "...";
*stream << TQString("subgraph \"cluster%1\" { label=\"%2\";\n")
- .arg(cluster).arg(iabr);
+ .tqarg(cluster).tqarg(iabr);
}
GraphNode* np;
@@ -630,17 +630,17 @@ void GraphExporter::writeDot()
if ((int)abr.length() > Configuration::maxSymbolLength())
abr = abr.left(Configuration::maxSymbolLength()) + "...";
- *stream << TQString(" F%1 [").arg((long)f, 0, 16);
+ *stream << TQString(" F%1 [").tqarg((long)f, 0, 16);
if (_useBox) {
// make label 3 lines for CallGraphView
- *stream << TQString("shape=box,label=\"** %1 **\\n**\\n%2\"];\n")
- .arg(abr)
- .arg(SubCost(np->incl).pretty());
+ *stream << TQString("tqshape=box,label=\"** %1 **\\n**\\n%2\"];\n")
+ .tqarg(abr)
+ .tqarg(SubCost(np->incl).pretty());
}
else
*stream << TQString("label=\"%1\\n%2\"];\n")
- .arg(abr)
- .arg(SubCost(np->incl).pretty());
+ .tqarg(abr)
+ .tqarg(SubCost(np->incl).pretty());
}
if (_go->clusterGroups() && i)
@@ -675,17 +675,17 @@ void GraphExporter::writeDot()
to.callerSet.remove(&e);
*stream << TQString(" F%1 -> F%2 [weight=%3")
- .arg((long)e.from(), 0, 16)
- .arg((long)e.to(), 0, 16)
- .arg((long)log(log(e.cost)));
+ .tqarg((long)e.from(), 0, 16)
+ .tqarg((long)e.to(), 0, 16)
+ .tqarg((long)log(log(e.cost)));
if (_go->detailLevel() ==1)
*stream << TQString(",label=\"%1\"")
- .arg(SubCost(e.cost).pretty());
+ .tqarg(SubCost(e.cost).pretty());
else if (_go->detailLevel() ==2)
*stream << TQString(",label=\"%3\\n%4 x\"")
- .arg(SubCost(e.cost).pretty())
- .arg(SubCost(e.count).pretty());
+ .tqarg(SubCost(e.cost).pretty())
+ .tqarg(SubCost(e.count).pretty());
*stream << TQString("];\n");
}
@@ -713,14 +713,14 @@ void GraphExporter::writeDot()
e->cost = costSum;
e->count = countSum;
- *stream << TQString(" R%1 [shape=point,label=\"\"];\n")
- .arg((long)n.function(), 0, 16);
+ *stream << TQString(" R%1 [tqshape=point,label=\"\"];\n")
+ .tqarg((long)n.function(), 0, 16);
*stream << TQString(" R%1 -> F%2 [label=\"%3\\n%4 x\",weight=%5];\n")
- .arg((long)n.function(), 0, 16)
- .arg((long)n.function(), 0, 16)
- .arg(SubCost(costSum).pretty())
- .arg(SubCost(countSum).pretty())
- .arg((int)log(costSum));
+ .tqarg((long)n.function(), 0, 16)
+ .tqarg((long)n.function(), 0, 16)
+ .tqarg(SubCost(costSum).pretty())
+ .tqarg(SubCost(countSum).pretty())
+ .tqarg((int)log(costSum));
}
costSum = countSum = 0.0;
@@ -736,14 +736,14 @@ void GraphExporter::writeDot()
e->cost = costSum;
e->count = countSum;
- *stream << TQString(" S%1 [shape=point,label=\"\"];\n")
- .arg((long)n.function(), 0, 16);
+ *stream << TQString(" S%1 [tqshape=point,label=\"\"];\n")
+ .tqarg((long)n.function(), 0, 16);
*stream << TQString(" F%1 -> S%2 [label=\"%3\\n%4 x\",weight=%5];\n")
- .arg((long)n.function(), 0, 16)
- .arg((long)n.function(), 0, 16)
- .arg(SubCost(costSum).pretty())
- .arg(SubCost(countSum).pretty())
- .arg((int)log(costSum));
+ .tqarg((long)n.function(), 0, 16)
+ .tqarg((long)n.function(), 0, 16)
+ .tqarg(SubCost(costSum).pretty())
+ .tqarg(SubCost(countSum).pretty())
+ .tqarg((int)log(costSum));
}
}
}
@@ -1062,7 +1062,7 @@ CanvasNode::CanvasNode(CallGraphView* v, GraphNode* n,
double inclP = 100.0 * n->incl / total;
if (_view->topLevel()->showPercentage())
setText(1, TQString("%1 %")
- .arg(inclP, 0, 'f', Configuration::percentPrecision()));
+ .tqarg(inclP, 0, 'f', Configuration::percentPrecision()));
else
setText(1, SubCost(n->incl).pretty());
setPixmap(1, percentagePixmap(25,10,(int)(inclP+.5), TQt::blue, true));
@@ -1096,7 +1096,7 @@ void CanvasNode::drawShape(TQPainter& p)
if (StoredDrawParams::selected() && _view->hasFocus()) {
_view->tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, r,
- _view->colorGroup());
+ _view->tqcolorGroup());
}
// draw afterwards to always get a frame even when zoomed
@@ -1121,7 +1121,7 @@ CanvasEdgeLabel::CanvasEdgeLabel(CallGraphView* v, CanvasEdge* ce,
if (!e) return;
setPosition(1, DrawParams::TopCenter);
- setText(1, TQString("%1 x").arg(SubCost(e->count).pretty()));
+ setText(1, TQString("%1 x").tqarg(SubCost(e->count).pretty()));
setPosition(0, DrawParams::BottomCenter);
@@ -1142,7 +1142,7 @@ CanvasEdgeLabel::CanvasEdgeLabel(CallGraphView* v, CanvasEdge* ce,
double inclP = 100.0 * e->cost / total;
if (_view->topLevel()->showPercentage())
setText(0, TQString("%1 %")
- .arg(inclP, 0, 'f', Configuration::percentPrecision()));
+ .tqarg(inclP, 0, 'f', Configuration::percentPrecision()));
else
setText(0, SubCost(e->cost).pretty());
setPixmap(0, percentagePixmap(25,10,(int)(inclP+.5), TQt::blue, true));
@@ -1331,7 +1331,7 @@ void CallGraphTip::maybeTip( const TQPoint& pos )
if (0) qDebug("CallGraphTip: Mouse on Node '%s'",
n->function()->prettyName().ascii());
- TQString tipStr = TQString("%1 (%2)").arg(cn->text(0)).arg(cn->text(1));
+ TQString tipStr = TQString("%1 (%2)").tqarg(cn->text(0)).tqarg(cn->text(1));
TQPoint vPosTL = cgv->contentsToViewport(i->boundingRect().topLeft());
TQPoint vPosBR = cgv->contentsToViewport(i->boundingRect().bottomRight());
tip(TQRect(vPosTL, vPosBR), tipStr);
@@ -1356,7 +1356,7 @@ void CallGraphTip::maybeTip( const TQPoint& pos )
tipStr = e->prettyName();
else
tipStr = TQString("%1 (%2)")
- .arg(ce->label()->text(0)).arg(ce->label()->text(1));
+ .tqarg(ce->label()->text(0)).tqarg(ce->label()->text(1));
tip(TQRect(pos.x()-5,pos.y()-5,pos.x()+5,pos.y()+5), tipStr);
}
}
@@ -1589,7 +1589,7 @@ void CallGraphView::keyPressEvent(TQKeyEvent* e)
TraceFunction* f = 0;
TraceCall* c = 0;
// rotate arrow key meaning for LeftRight layout
int key = e->key();
if (_layout == LeftRight) {
switch(key) {
@@ -1745,7 +1745,7 @@ void CallGraphView::doUpdate(int changeType)
}
if (changeType & dataChanged) {
- // invalidate old selection and graph part
+ // tqinvalidate old selection and graph part
_exporter.reset(_data, _activeItem, _costType, _groupType);
_selectedNode = 0;
_selectedEdge = 0;
@@ -1792,8 +1792,8 @@ void CallGraphView::showRenderWarning()
s = i18n("Layouting stopped.\n");
s.append(i18n("The call graph has %1 nodes and %2 edges.\n")
- .arg(_exporter.nodeCount())
- .arg(_exporter.edgeCount()));
+ .tqarg(_exporter.nodeCount())
+ .tqarg(_exporter.edgeCount()));
showText(s);
}
@@ -1866,7 +1866,7 @@ void CallGraphView::refresh()
if ( !_renderProcess->start() ) {
TQString e = i18n("No call graph is available because the following\n"
"command cannot be run:\n'%1'\n")
- .arg(_renderProcess->arguments().join(" "));
+ .tqarg(_renderProcess->arguments().join(" "));
e += i18n("Please check that 'dot' is installed (package GraphViz).");
showText(e);
@@ -2206,7 +2206,7 @@ void CallGraphView::dotExited()
TQString s = i18n("There is no call graph available for function\n"
"\t'%1'\n"
"because it has no cost of the selected event type.");
- TQCanvasText* t = new TQCanvasText(s.arg(_activeItem->name()), _canvas);
+ TQCanvasText* t = new TQCanvasText(s.tqarg(_activeItem->name()), _canvas);
// t->setTextFlags(TQt::AlignHCenter | TQt::AlignVCenter);
t->move(5,5);
t->show();
@@ -2394,10 +2394,10 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
TQString name = f->prettyName();
popup.insertItem(i18n("Go to '%1'")
- .arg(Configuration::shortenSymbol(name)), 93);
+ .tqarg(Configuration::shortenSymbol(name)), 93);
if (cycle && (cycle != f)) {
name = Configuration::shortenSymbol(cycle->prettyName());
- popup.insertItem(i18n("Go to '%1'").arg(name), 94);
+ popup.insertItem(i18n("Go to '%1'").tqarg(name), 94);
}
popup.insertSeparator();
}
@@ -2416,7 +2416,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
if (c) {
TQString name = c->prettyName();
popup.insertItem(i18n("Go to '%1'")
- .arg(Configuration::shortenSymbol(name)), 95);
+ .tqarg(Configuration::shortenSymbol(name)), 95);
popup.insertSeparator();
}
@@ -2457,7 +2457,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
case 10: gpopup1.setItemChecked(104,true); break;
case 15: gpopup1.setItemChecked(105,true); break;
default:
- gpopup1.insertItem(i18n("< %1").arg(_maxCallerDepth), 106);
+ gpopup1.insertItem(i18n("< %1").tqarg(_maxCallerDepth), 106);
gpopup1.setItemChecked(106,true); break;
}
@@ -2480,7 +2480,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
case 10: gpopup2.setItemChecked(114,true); break;
case 15: gpopup2.setItemChecked(115,true); break;
default:
- gpopup2.insertItem(i18n("< %1").arg(_maxCallingDepth), 116);
+ gpopup2.insertItem(i18n("< %1").tqarg(_maxCallingDepth), 116);
gpopup2.setItemChecked(116,true); break;
}
@@ -2701,7 +2701,7 @@ void CallGraphView::readViewConfig(KConfig* c,
_clusterGroups = g->readBoolEntry("ClusterGroups",
DEFAULT_CLUSTERGROUPS);
_detailLevel = g->readNumEntry("DetailLevel", DEFAULT_DETAILLEVEL);
- _layout = GraphOptions::layout(g->readEntry("Layout",
+ _layout = GraphOptions::tqlayout(g->readEntry("Layout",
layoutString(DEFAULT_LAYOUT)));
_zoomPosition = zoomPos(g->readEntry("ZoomPosition",
zoomPosString(DEFAULT_ZOOMPOS)));
@@ -1589,7 +1589,7 @@ void CallGraphView::keyPressEvent(TQKeyEvent* e)
TraceFunction* f = 0;
TraceCall* c = 0;
- // rotate arrow key meaning for LeftRight layout
+ // rotate arrow key meaning for LeftRight tqlayout
int key = e->key();
if (_layout == LeftRight) {